[Treepkg-commits] r287 - in branches/scratchbox: bin treepkg

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Fri Apr 16 13:07:37 CEST 2010


Author: bricks
Date: 2010-04-16 13:07:35 +0200 (Fri, 16 Apr 2010)
New Revision: 287

Modified:
   branches/scratchbox/bin/initpbuilder.py
   branches/scratchbox/treepkg/sbuilder.py
Log:
bugfix: sbdmock builder tried to check self.builderconfig which wasn't set yet
renamed pbuilder to builder at several places


Modified: branches/scratchbox/bin/initpbuilder.py
===================================================================
--- branches/scratchbox/bin/initpbuilder.py	2010-04-16 10:59:13 UTC (rev 286)
+++ branches/scratchbox/bin/initpbuilder.py	2010-04-16 11:07:35 UTC (rev 287)
@@ -6,11 +6,11 @@
 # This program is free software under the GPL (>=v2)
 # Read the file COPYING coming with the software for details.
 
 """Script to initialize the pbuilder environment for the tree packager
 
 The script assumes that the config file for the tree packager already
-contains the pbuilder settings.  Also, this script assumes that there is
-only one pbuilder setting for all packagers.
+contains the builder settings.  Also, this script assumes that there is
+only one builder setting for all packagers.
 """
 
 import sys
@@ -6,11 +6,11 @@
 # Read the file COPYING coming with the software for details.
 
-"""Script to initialize the pbuilder environment for the tree packager
+"""Script to initialize the builder environment for the tree packager
 
 The script assumes that the config file for the tree packager already

Modified: branches/scratchbox/treepkg/sbuilder.py
===================================================================
--- branches/scratchbox/treepkg/sbuilder.py	2010-04-16 10:59:13 UTC (rev 286)
+++ branches/scratchbox/treepkg/sbuilder.py	2010-04-16 11:07:35 UTC (rev 287)
@@ -31,9 +31,9 @@
     extra_pkg_dir = util.filenameproperty("extra-pkg")
 
     def __init__(self, builderconfig, root_cmd, release_signing_keyid=None):
         """Initialize the PBuilder instance with the configuration file.
         The root_cmd parameter should be a list with a command that can
-        be used to get root permissions to run pbuilder.  It may be an
+        be used to get root permissions.  It may be an
         empty list if no command is needed.  It's a list so that
         commands with several shell-words can be used without having to
         worry about quoting.
@@ -42,7 +42,7 @@
             raise RuntimeError("Config file %s for sbdmock does not exist.",
                   builderconfig)
 
-        if not os.path.isabs(self.builderconfig):
+        if not os.path.isabs(builderconfig):
             raise RuntimeError("Config file %s must be an absolute filename.",
                   builderconfig)
 
@@ -55,7 +55,7 @@
     def init_builder(self, distribution, mirrorsite, extramirrors):
         """Initializes the builder instance"""
 
-        basedir = os.path.dirname(self.pbuilderrc)
+        basedir = os.path.dirname(self.builderconfig)
         replacements = dict(basedir=basedir,
                             distribution=distribution,
                             mirrorsite=mirrorsite)
@@ -80,7 +80,7 @@
         self.update_extra_pkg_dir()
 
     def update(self, suppress_output=True, log_info=True):
-        """Runs pbuilder update on this pbuilder instance"""
+        """Runs nothing"""
         if log_info:
             logging.info("Update of apt cache is done on every start. skipping ...")
 
@@ -92,14 +92,14 @@
            binary_dir -- name of the directory to receive the binary packages
            logfile -- name of the logfile of the build
            bindmounts -- Sequence of directory names that should be
                          bind-mounted in the pbuilder chroot
                          environment
            extra_packages -- Extra packages to install
            extra_env -- mapping with extra environment variables to set
                         when runing the pbuilder process.  If pbuilder
                         is started via sudo, make sure that sudo does
                         not remove these variables when it starts
-                        pbuilder
+                        builder
         """
         args = []
         if logfile is not None:
@@ -144,23 +144,23 @@
             self.umount_all()
 
     def run_script(self, script, logfile, bindmounts=(), save_after_exec=False):
         """Execute a script in pbuilder's chroot environment
         Parameters:
            script -- A list of strings with the command line to invoke the
                      script
            logfile -- name of the logfile of the build
            bindmounts -- Sequence of directory names that should be
                          bind-mounted in the pbuilder chroot
                          environment (optional)
            save_after_exec -- Boolean indicating whether the chroot
                               environment should be copied back so that
                               modifications are available in subsequent
                               uses of the pbuilder instance.
         """
         logging.error("It isn't possible to run scripts withon sbdmock.")
 
     def login(self, bindmounts=(), save_after_login=False):
         """Start an interactive shell in the pbuilder environment"""
         args = []
         for mount in bindmounts:
             args.extend(["--bindmounts", mount])
@@ -31,9 +31,9 @@
 
     def __init__(self, builderconfig, root_cmd, release_signing_keyid=None):
-        """Initialize the PBuilder instance with the configuration file.
+        """Initialize the Builder instance with the configuration file.
         The root_cmd parameter should be a list with a command that can
@@ -92,14 +92,14 @@
            logfile -- name of the logfile of the build
            bindmounts -- Sequence of directory names that should be
-                         bind-mounted in the pbuilder chroot
+                         bind-mounted in the builder chroot
                          environment
            extra_packages -- Extra packages to install
@@ -92,14 +92,14 @@
            extra_packages -- Extra packages to install
            extra_env -- mapping with extra environment variables to set
-                        when runing the pbuilder process.  If pbuilder
+                        when runing the builder process.  If builder
                         is started via sudo, make sure that sudo does
                         not remove these variables when it starts
@@ -144,23 +144,23 @@
 
     def run_script(self, script, logfile, bindmounts=(), save_after_exec=False):
-        """Execute a script in pbuilder's chroot environment
+        """Execute a script in builder's chroot environment
         Parameters:
            script -- A list of strings with the command line to invoke the
@@ -144,23 +144,23 @@
            logfile -- name of the logfile of the build
            bindmounts -- Sequence of directory names that should be
-                         bind-mounted in the pbuilder chroot
+                         bind-mounted in the builder chroot
                          environment (optional)
            save_after_exec -- Boolean indicating whether the chroot
@@ -144,23 +144,23 @@
                               environment should be copied back so that
                               modifications are available in subsequent
-                              uses of the pbuilder instance.
+                              uses of the builder instance.
         """
         logging.error("It isn't possible to run scripts withon sbdmock.")
@@ -144,23 +144,23 @@
 
     def login(self, bindmounts=(), save_after_login=False):
-        """Start an interactive shell in the pbuilder environment"""
+        """Start an interactive shell in the builder environment"""
         args = []
         for mount in bindmounts:



More information about the Treepkg-commits mailing list